@@ -27,7 +27,7 @@ from mitosheet.step_performers.import_steps.simple_import import \
 from mitosheet.transpiler.transpile import transpile
 from mitosheet.updates import UPDATES
 from mitosheet.user.utils import is_pro, is_running_test
-from mitosheet.utils import (dfs_to_array_for_json, get_new_id,
+from mitosheet.utils import (NpEncoder, dfs_to_array_for_json, get_new_id,
                              is_default_df_names)
 
 
@@ -60,7 +60,9 @@ def execute_step_list_from_index(
 
     If start_index is not given, will start from the initialize step.
     """
-    if start_index is None or start_index < 0:
+
+    # Make sure start index is not None
+    if start_index is None:
         start_index = 0
 
     # Get the steps to skip, so that we can skip them
@@ -77,7 +79,7 @@ def execute_step_list_from_index(
         if step_index in step_indexes_to_skip:
             new_step_list.append(step)
             continue
-
+            
         # Create a new step with the same params
         new_step = Step(step.step_type, step.step_id, step.params)
 
@@ -283,7 +285,7 @@ class StepsManager:
         self.saved_sheet_data = array
         self.last_step_index_we_wrote_sheet_json_on = self.curr_step_idx
 
-        return json.dumps(array)
+        return json.dumps(array, cls=NpEncoder)
 
     @property
     def analysis_data_json(self):
@@ -444,9 +446,17 @@ class StepsManager:
 
             # The last valid index is the minimum of the newly skipped things - 1
             # or the last valid step (if nothing is skipped)
-            # TODO: we can improve this in the future to remember what it executed last time
-            # and so do less work!
             last_valid_index = min(newly_skipped_indexes.union({len(self.steps)})) - 1
+
+        # Make sure that this step isn't itself skipped, and decrement until it is not
+        all_skipped_indexes = get_step_indexes_to_skip(new_steps)
+        while last_valid_index in all_skipped_indexes:
+            last_valid_index -= 1
+
+        # Make sure that this index is positive -- it always should be!
+        if last_valid_index < 0:
+            return 0
+
         return last_valid_index
 
     def execute_undo(self):
